==> openjdk13-13.0.13_0+release+server.darwin_16.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_sw_KE.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_sw_KE extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AF", "Afghanistani" },
            { "AI", "Anguila" },
            { "AQ", "Antaktika" },
            { "AZ", "Azabajani" },
            { "BJ", "Benini" },
            { "BT", "Bhutani" },
            { "BY", "Belarusi" },
            { "CC", "Visiwa vya Kokos (Keeling)" },
            { "CD", "Kongo - Kinshasa" },
            { "CI", "Ivorikosti" },
            { "CY", "Saiprasi" },
            { "DK", "Denmaki" },
            { "EA", "Keuta na Melilla" },
            { "EC", "Ekwado" },
            { "FM", "Mikronesia" },
            { "GA", "Gaboni" },
            { "GL", "Grinilandi" },
            { "GP", "Gwadelupe" },
            { "GS", "Visiwa vya Jojia ya Kusini na Sandwich ya Kusini" },
            { "GU", "Guami" },
            { "HR", "Kroashia" },
            { "IO", "Himaya ya Uingereza katika Bahari Hindi" },
            { "JO", "Yordani" },
            { "KY", "Visiwa vya Kaimani" },
            { "LA", "Laosi" },
            { "LB", "Lebanoni" },
            { "LI", "Lishenteni" },
            { "LS", "Lesotho" },
            { "LU", "Lasembagi" },
            { "LV", "Lativia" },
            { "MA", "Moroko" },
            { "MC", "Monako" },
            { "MK", "Masedonia" },
            { "MM", "Myama (Burma)" },
            { "MO", "Makau SAR China" },
            { "MQ", "Martiniki" },
            { "MS", "Montserati" },
            { "MV", "Maldivi" },
            { "NC", "Nyukaledonia" },
            { "NE", "Nijeri" },
            { "NO", "Norwe" },
            { "NP", "Nepali" },
            { "OM", "Omani" },
            { "PF", "Polinesia ya Ufaransa" },
            { "PG", "Papua Guinea Mpya" },
            { "PL", "Polandi" },
            { "PR", "Puetoriko" },
            { "PS", "Himaya za Palestina" },
            { "PY", "Paragwai" },
            { "QA", "Katari" },
            { "SG", "Singapuri" },
            { "SR", "Surinamu" },
            { "ST", "Sao Tome na Prinsipe" },
            { "SY", "Shamu" },
            { "TD", "Chadi" },
            { "TH", "Thailandi" },
            { "TM", "Turukimenstani" },
            { "TW", "Taiwani" },
            { "UA", "Ukreni" },
            { "UY", "Urugwai" },
            { "VA", "Mji wa Vatikani" },
            { "VG", "Visiwa vya Virgin vya Uingereza" },
            { "VI", "Visiwa vya Virgin vya Marekani" },
            { "VN", "Vietnamu" },
            { "YT", "Mayote" },
            { "as", "Kiasamisi" },
            { "cu", "Kislovakia cha Kanisa la Jadi" },
            { "hy", "Kiamenia" },
            { "km", "Kikhmeri" },
            { "kn", "Kikanada" },
            { "li", "Kilimbugishi" },
            { "mk", "Kimasedonia" },
            { "or", "Kiodia" },
            { "tw", "Kitwi" },
            { "ug", "Kiuiguri" },
            { "arq", "Kiarabu cha Aljeria" },
            { "chr", "Kicheroki" },
            { "gaa", "Kiga" },
            { "grc", "Kigiriki cha Kale" },
            { "gwi", "Kigwich\u02bcin" },
            { "hsb", "Kisorbia cha Juu" },
            { "hup", "Kihupa" },
            { "inh", "Kiingushi" },
            { "jbo", "Kilojbani" },
            { "kac", "Kikachini" },
            { "khq", "Kikoyrachiini" },
            { "kkj", "Kikako" },
            { "koi", "Kikomipermyak" },
            { "kru", "Kikurukh" },
            { "lag", "Kilangi" },
            { "lam", "Kilamba" },
            { "mdf", "Kimoksha" },
            { "mic", "Kimi'kmak" },
            { "moh", "Kimohoki" },
            { "nnh", "Kiingiemboon" },
            { "nqo", "Kiin\u2019ko" },
            { "pcm", "Kipijini cha Nigeria" },
            { "ses", "Kikoyraborosenni" },
            { "shu", "Kiarabu cha Chadi" },
            { "srn", "Kisranantongo" },
            { "swb", "Kikomoro" },
            { "syr", "Kisiria" },
            { "twq", "Kitasawak" },
            { "udm", "Kiudumurti" },
            { "zgh", "Kitamazighati Sanifu cha Moroko" },
            { "sw_CD", "Kiswahili cha Kongo" },
        };
        return data;
    }
}

==> openjdk15-15.0.9_0+release+server.darwin_16.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_sw_KE.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_sw_KE extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final String metaValue_or = "Kiodia";
        final Object[][] data = new Object[][] {
            { "PR", "Puetoriko" },
            { "hup", "Kihupa" },
            { "PS", "Himaya za Palestina" },
            { "moh", "Kimohoki" },
            { "PY", "Paragwai" },
            { "HR", "Kroashia" },
            { "kkj", "Kikako" },
            { "nqo", "Kiin\u2019ko" },
            { "Hebr", "Kihibrania" },
            { "QA", "Katari" },
            { "hy", "Kiamenia" },
            { "Jamo", "Kijamo" },
            { "type.nu.mymr", "Nambari za Kimyama" },
            { "YT", "Mayote" },
            { "AF", "Afghanistani" },
            { "IO", "Himaya ya Uingereza katika Bahari Hindi" },
            { "type.ca.ethiopic", "Kalenda ya Kihabeshi" },
            { "AI", "Anguila" },
            { "type.nu.geor", "Nambari za Kijiojia" },
            { "AQ", "Antaktika" },
            { "Ethi", "Kihabeshi" },
            { "as", "Kiasamisi" },
            { "Hira", "Kihiragana" },
            { "jbo", "Kilojbani" },
            { "AZ", "Azabajani" },
            { "JO", "Yordani" },
            { "mic", "Kimi'kmak" },
            { "BJ", "Benini" },
            { "twq", "Kitasawak" },
            { "BT", "Bhutani" },
            { "SG", "Singapuri" },
            { "Mymr", "Kimyama" },
            { "BY", "Belarusi" },
            { "type.nu.hebr", "Nambari za Kihibrania" },
            { "SR", "Surinamu" },
            { "CC", "Visiwa vya Kokos (Keeling)" },
            { "ses", "Kikoyraborosenni" },
            { "CD", "Kongo - Kinshasa" },
            { "ST", "Sao Tome na Prinsipe" },
            { "arq", "Kiarabu cha Aljeria" },
            { "km", "Kikhmeri" },
            { "kn", "Kikanada" },
            { "CI", "Ivorikosti" },
            { "SY", "Shamu" },
            { "Orya", metaValue_or },
            { "KY", "Visiwa vya Kaimani" },
            { "TD", "Chadi" },
            { "cu", "Kislovakia cha Kanisa la Jadi" },
            { "CV", "Kepuvede" },
            { "TH", "Thailandi" },
            { "LA", "Laosi" },
            { "CY", "Saiprasi" },
            { "LB", "Lebanoni" },
            { "gwi", "Kigwich\u02bcin" },
            { "type.nu.ethi", "Nambari za Kihabeshi" },
            { "type.nu.mlym", "Nambari za Kimalayalam" },
            { "TM", "Turukimenstani" },
            { "LI", "Lishenteni" },
            { "li", "Kilimbugishi" },
            { "swb", "Kikomoro" },
            { "TW", "Taiwani" },
            { "tw", "Kitwi" },
            { "koi", "Kikomipermyak" },
            { "DK", "Denmaki" },
            { "LS", "Lesotho" },
            { "Brai", "Breli" },
            { "LU", "Lasembagi" },
            { "LV", "Lativia" },
            { "UA", "Ukreni" },
            { "sw_CD", "Kiswahili cha Kongo" },
            { "ug", "Kiuiguri" },
            { "lag", "Kilangi" },
            { "MA", "Moroko" },
            { "MC", "Monako" },
            { "lam", "Kilamba" },
            { "EA", "Keuta na Melilla" },
            { "EC", "Ekwado" },
            { "MK", "Masedonia" },
            { "mk", "Kimasedonia" },
            { "MM", "Myama (Burma)" },
            { "MQ", "Martiniki" },
            { "UY", "Urugwai" },
            { "MS", "Montserati" },
            { "MV", "Maldivi" },
            { "nnh", "Kiingiemboon" },
            { "VA", "Mji wa Vatikani" },
            { "chr", "Kicheroki" },
            { "mdf", "Kimoksha" },
            { "VG", "Visiwa vya Virgin vya Uingereza" },
            { "VI", "Visiwa vya Virgin vya Marekani" },
            { "202", "Kusini mwa Jangwa la Sahara" },
            { "type.ca.hebrew", "Kalenda ya kihibrania" },
            { "NC", "Nyukaledonia" },
            { "khq", "Kikoyrachiini" },
            { "hsb", "Kisorbia cha Juu" },
            { "NE", "Nijeri" },
            { "key.hc", "Kipindi cha saa (12 dhidi ya 24)" },
            { "VN", "Vietnamu" },
            { "udm", "Kiudumurti" },
            { "NO", "Norwe" },
            { "shu", "Kiarabu cha Chadi" },
            { "NP", "Nepali" },
            { "gaa", "Kiga" },
            { "FM", "Mikronesia" },
            { "key.va", "Tofauti ya Lugha" },
            { "Taml", "Kitamili" },
            { "kac", "Kikachini" },
            { "syr", "Kisiria" },
            { "grc", "Kigiriki cha Kale" },
            { "GA", "Gaboni" },
            { "zgh", "Kitamazighati Sanifu cha Moroko" },
            { "pcm", "Kipijini cha Nigeria" },
            { "type.nu.tamldec", "Nambari za Kitamili" },
            { "OM", "Omani" },
            { "inh", "Kiingushi" },
            { "or", metaValue_or },
            { "GL", "Grinilandi" },
            { "GP", "Gwadelupe" },
            { "XA", "Kiinitoni cha kigeni" },
            { "XB", "Pseudo-Bidi" },
            { "GS", "Visiwa vya Jojia ya Kusini na Sandwich ya Kusini" },
            { "GU", "Guami" },
            { "srn", "Kisranantongo" },
            { "kru", "Kikurukh" },
            { "PF", "Polinesia ya Ufaransa" },
            { "PG", "Papua Guinea Mpya" },
            { "PL", "Polandi" },
            { "type.ca.dangi", "Kalenda ya Kidangi" },
        };
        return data;
    }
}
